# -*- coding: utf-8 -*-

# Copyright (C) 2007-2012 Thomas Perl <thp.io/about>
# Copyright (C) 2014 kaliko <kaliko@azylum.org>

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 3 only.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .plugin import Plugin, botcmd

class Echo(Plugin):

    def __init__(self, bot):
        Plugin.__init__(self, bot)
        bot.add_event_handler('groupchat_message', self.muc_message)
        # The groupchat_presence event is triggered whenever a
        # presence stanza is received from any chat room, including
        # any presences you send yourself. To limit event handling
        # to a single room, use the events muc::room@server::presence,
        # muc::room@server::got_online, or muc::room@server::got_offline.
        #bot.add_event_handler("muc::%s::got_online" % self.bot.room, self.muc_online)

    def muc_message(self, msg):
        """
        Process incoming message stanzas from any chat room. Be aware
        that if you also have any handlers for the 'message' event,
        message stanzas may be processed by both handlers, so check
        the 'type' attribute when using a 'message' event handler.

        Whenever the bot's nickname is mentioned, respond to
        the message.

        IMPORTANT: Always check that a message is not from yourself,
                   otherwise you will create an infinite loop responding
                   to your own messages.

        This handler will reply to messages that mention
        the bot's nickname.

        Arguments:
            msg -- The received message stanza. See the documentation
                   for stanza objects and the Message stanza to see
                   how it may be used.
        """
        if msg['mucnick'] != self.bot.nick and self.bot.nick in msg['body']:
            self.bot.send_message(mto=msg['from'].bare,
                              mbody='I heard that, %s.' % msg['mucnick'],
                              mtype='groupchat')

    def muc_online(self, presence):
        """
        Process a presence stanza from a chat room. In this case,
        presences from users that have just come online are
        handled by sending a welcome message that includes
        the user's nickname and role in the room.

        Arguments:
            presence -- The received presence stanza. See the
                        documentation for the Presence stanza
                        to see how else it may be used.
        """
        if presence['muc']['nick'] != self.bot.nick:
            self.bot.send_message(mto=presence['from'].bare,
                              mbody='Hello, %s %s' % (presence['muc']['role'],
                                                      presence['muc']['nick']),
                              mtype='groupchat')

    @botcmd
    def tell(self, message, args):
        pass

# VIM MODLINE
# vim: ai ts=4 sw=4 sts=4 expandtab
